@@ -1,7 +1,9 @@
 package Kephra::App;
+use strict;
+use warnings;
+
 our $VERSION = '0.06';
 
-use strict;
 use Wx qw(
 	wxDefaultPosition wxDefaultSize   wxGROW wxTOP wxBOTTOM wxVERTICAL 
 	wxSTAY_ON_TOP wxSIMPLE_BORDER wxFRAME_NO_TASKBAR
@@ -56,27 +58,60 @@ sub assemble_layout {
 	Kephra::App::TabBar::show();
 }
 
+sub setup_logging {
+    require Log::Dispatch;
+    require Log::Dispatch::File;
+    mkdir $Kephra::temp{path}{logger};
+    # TODO: setup pseudo logger in case the directory does not exist or
+    # otherwise cannot start the logger, report error
+    $::logger = Log::Dispatch->new;
+    require POSIX;
+    my $ts = POSIX::strftime("%Y%m%d", localtime);
+    $main::logger->add( Log::Dispatch::File->new( 
+            name        => 'file1',
+            min_level   => ($ENV{KEPHRA_LOGGIN} || 'debug'),
+            filename    => File::Spec->catfile($Kephra::temp{path}{logger}, "$ts.log"),
+            mode        => 'append',
+            callbacks   => \&_logger,
+            ));
+    $main::logger->info("Starting");
+
+    $SIG{__WARN__} = sub { $main::logger->warn($_[0]) };
+
+    return;
+}
+
+sub _logger {
+    my %data = @_;
+    # TODO maybe we should use regular timestamp here and turn on the hires timestamp
+    # only if KEPHRA_TIME or similar env variable is set
+    require Time::HiRes;
+    return sprintf("%s - %s - %s - %s\n", Time::HiRes::time(), $$, $data{level}, $data{message});
+}
 
 sub start {
-	use Benchmark qw(:all);
-	my $t0 = new Benchmark;
+	use Benchmark ();
+	my $t0 = new Benchmark if $Kephra::BENCHMARK;
 	my $app = shift;
 	_ref($app);
 	Kephra::Config::init();
+	#setup_logging();
 	splashscreen();             # 2'nd splashscreen can close when app is ready
 	Wx::InitAllImageHandlers();
 	my $frame = Kephra::App::Window::create();
 	my $ep = Kephra::App::EditPanel::create();
 	$Kephra::temp{document}{open}[0]{pointer} = $ep->GetDocPointer();
 	$Kephra::temp{document}{buffer} = 1;
+	#$main::logger->debug("init app pntr");
 	print " init app pntr:",
 		Benchmark::timestr( Benchmark::timediff( new Benchmark, $t0 ) ), "\n"
-		if $Kephra::benchmark;
+		if $Kephra::BENCHMARK;
 	my $t1 = new Benchmark;
 	Kephra::Config::Global::load_autosaved();
+	#$main::logger->debug("glob cfg load");
 	print " glob cfg load:",
 		Benchmark::timestr( Benchmark::timediff( new Benchmark, $t1 ) ), "\n"
-		if $Kephra::benchmark;
+		if $Kephra::BENCHMARK;
 	my $t2 = new Benchmark;
 	if (Kephra::Config::Global::evaluate()) {
 		#Kephra::API::EventTable::freeze_all();
@@ -85,23 +120,23 @@ sub start {
 		$frame->Show(1);
 		print " configs eval:",
 			Benchmark::timestr( Benchmark::timediff( new Benchmark, $t2 ) ), "\n"
-			if $Kephra::benchmark;
+			if $Kephra::BENCHMARK;
 		my $t3 = new Benchmark;
 		Kephra::File::Session::autoload();
 		Kephra::Document::Internal::add($_) for @ARGV;
 		print " file session:",
 			Benchmark::timestr( Benchmark::timediff( new Benchmark, $t3 ) ), "\n"
-			if $Kephra::benchmark;
+			if $Kephra::BENCHMARK;
 		my $t4 = new Benchmark;
 		Kephra::File::History::init();
 		#Kephra::API::EventTable::thaw_all();
 		Kephra::API::EventTable::connect_all();
 		print " event table:",
 			Benchmark::timestr( Benchmark::timediff( new Benchmark, $t4 ) ), "\n"
-			if $Kephra::benchmark;
+			if $Kephra::BENCHMARK;
 		print "app startet:",
 			Benchmark::timestr( Benchmark::timediff( new Benchmark, $t0 ) ), "\n"
-			if $Kephra::benchmark;
+			if $Kephra::BENCHMARK;
 			1;                      # everything is good
 	} else {
 		$app->ExitMainLoop(1);
@@ -121,7 +156,7 @@ sub exit {
 	Kephra::App::Window::destroy(); # close window
 	print "shut down in:",
 		Benchmark::timestr( Benchmark::timediff( new Benchmark, $t0 ) ), "\n"
-		if $Kephra::benchmark;
+		if $Kephra::BENCHMARK;
 }
 
 sub raw_exit { Wx::Window::Destroy(shift) }
