@@ -1,7 +1,9 @@
 package Kephra::Document::Internal;
-$VERSION = '0.10';
-
 use strict;
+use warnings;
+
+our $VERSION = '0.10';
+
 use Wx qw(wxYES wxNO);
 
 
@@ -272,4 +274,4 @@ sub dissect_path {
 # depreciated
 sub set_path_slashes_to_OS_standart{ File::Spec->canonpath( shift ) }
 
-1;
\ No newline at end of file
+1;
