@@ -1,13 +1,15 @@
 package Kephra::Module::Demo;
-$VERSION = '0.01';
+use strict;
+use warnings;
+
+our $VERSION = '0.01';
 
 #################################################
 # Demoplugin as an tutorial for plugin authors
 #################################################
 
-use strict;
 
 sub start{
 }
 
-1;
\ No newline at end of file
+1;
